"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CoinspotApiBase = void 0;
const axios_1 = __importDefault(require("axios"));
const crypto_1 = __importDefault(require("crypto"));
class CoinspotApiBase {
    constructor(key, secret) {
        this.key = key;
        this.secret = secret;
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    async request(path, data = {}, readOnly = false) {
        const nonce = Date.now();
        const payload = { ...data, nonce };
        const stringPayload = JSON.stringify(payload);
        const signature = crypto_1.default
            .createHmac('sha512', this.secret)
            .update(stringPayload)
            .digest('hex');
        const config = {
            method: 'POST',
            url: `https://www.coinspot.com.au/api/v2${readOnly ? '/ro' : ''}${path}`,
            headers: {
                'Content-Type': 'application/json',
                'sign': signature,
                'key': this.key,
            },
            data: stringPayload,
        };
        const response = await (0, axios_1.default)(config);
        return response.data;
    }
}
exports.CoinspotApiBase = CoinspotApiBase;
//# sourceMappingURL=coinspotApiBase.js.map