export type ReadOnlyApiStatusResponse = {
    status: string;
};
export type FullAccessApiStatusResponse = ReadOnlyApiStatusResponse;
export type BaseApiResponse = {
    status: string;
    message: string;
};
export type LatestPricesResponse = BaseApiResponse & {
    prices: {
        [coinType: string]: {
            bid: number;
            ask: number;
            last: number;
        };
    };
};
export type LatestCoinPricesResponse = BaseApiResponse & {
    prices: {
        bid: number;
        ask: number;
        last: number;
    };
};
export type LatestBuySellPriceResponse = BaseApiResponse & {
    rate: string;
    market: string;
};
export type OpenOrder = {
    amount: number;
    rate: number;
    total: number;
    coin: string;
    market: string;
};
export type OpenOrdersResponse = BaseApiResponse & {
    buyorders: OpenOrder[];
    sellorders: OpenOrder[];
};
export type CompletedOrder = OpenOrder & {
    solddate: string;
};
export type CompletedOrdersResponse = BaseApiResponse & {
    buyorders: CompletedOrder[];
    sellorders: CompletedOrder[];
};
export type CoinDepositAddressResponse = BaseApiResponse & {
    networks: {
        name: string;
        network: string;
        address: string;
        memo: string;
    }[];
};
export type BuySellQuoteResponse = BaseApiResponse & {
    rate: number;
};
export type SwapQuoteResponse = BaseApiResponse & {
    rate: number;
};
export type PlaceMarketBuySellOrderResponse = BaseApiResponse & {
    coin: string;
    market: string;
    amount: number;
    rate: number;
    id: string;
};
export type EditOpenMarketBuySellOrderResponse = BaseApiResponse & {
    updated: boolean;
    id: string;
    coin: string;
    rate: number;
    newrate: number;
    amount: number;
    total: number;
};
export type PlaceBuySellNowOrderResponse = BaseApiResponse & {
    coin: string;
    amount: number;
    market: string;
    total: number;
};
export type PlaceSwapNowOrderResponse = BaseApiResponse & {
    coin: string;
    amount: number;
    rate: number;
    market: string;
    total: number;
};
export type CancelOrderResponse = BaseApiResponse;
export type CoinWithdrawalDetailsResponse = BaseApiResponse & {
    networks: {
        network: string;
        paymentid: string;
        fee: number;
        minsend: number;
        default: boolean;
    }[];
};
export type WithdrawCoinResponse = BaseApiResponse;
export type MyCoinBalancesResponse = BaseApiResponse & {
    balances: {
        [coinType: string]: {
            balance: number;
            audbalance: number;
            rate: number;
        };
    }[];
};
export type MyCoinBalanceResponse = BaseApiResponse & {
    balance: {
        [coinType: string]: {
            balance: number;
            available?: number;
            audbalance: number;
            rate: number;
        };
    };
};
export type MyOpenMarketOrder = {
    id: string;
    coin: string;
    market: string;
    amount: number;
    created: string;
    rate: number;
    total: number;
};
export type MyOpenMarketOrdersResponse = BaseApiResponse & {
    buyorders: MyOpenMarketOrder[];
    sellorders: MyOpenMarketOrder[];
};
export type MyOpenLimitOrder = {
    id: string;
    coin: string;
    market: string;
    rate: number;
    amount: number;
    created: string;
    type: string;
};
export type MyOpenLimitOrdersResponse = BaseApiResponse & {
    buyorders: MyOpenLimitOrder[];
    sellorders: MyOpenLimitOrder[];
};
export type MyOrderHistoryItem = {
    id: string;
    coin: string;
    type: string;
    market: string;
    rate: number;
    amount: number;
    total: number;
    solddate: string;
    audfeeExGst: number;
    audGst: number;
    audtotal: number;
    otc?: boolean;
};
export type MyOrderHistoryResponse = BaseApiResponse & {
    buyorders: MyOrderHistoryItem[];
    sellorders: MyOrderHistoryItem[];
};
export type MySendTransaction = {
    timestamp: string;
    amount: number;
    coin: string;
    address: string;
    aud: number;
    sendfee: number;
};
export type MyReceiveTransaction = {
    timestamp: string;
    amount: number;
    coin: string;
    address: string;
    aud: number;
    from: string;
};
export type MySendReceiveHistoryResponse = BaseApiResponse & {
    sendtransactions: MySendTransaction[];
    receivetransactions: MyReceiveTransaction[];
};
export type MyDepositHistoryItem = {
    amount: number;
    created: string;
    status: string;
    type: string;
    reference: string;
};
export type MyDepositHistoryResponse = BaseApiResponse & {
    deposits: MyDepositHistoryItem[];
};
export type MyWithdrawalHistoryItem = {
    amount: number;
    created: string;
    status: string;
};
export type MyWithdrawalHistoryResponse = BaseApiResponse & {
    withdrawals: MyWithdrawalHistoryItem[];
};
export type MyAffiliatePayment = {
    amount: number;
    month: string;
};
export type MyAffiliatePaymentsResponse = BaseApiResponse & {
    payments: MyAffiliatePayment[];
};
export type MyReferralPayment = {
    amount: number;
    coin: string;
    audamount: number;
    timestamp: string;
};
export type MyReferralPaymentsResponse = BaseApiResponse & {
    payments: MyReferralPayment[];
};
//# sourceMappingURL=index.d.ts.map